@@ -458,7 +458,7 @@ def random_bytes(n):
         random.seed(int(params['seed']))
 
     response = make_response()
-    response.data = bytes().join(chr(random.randint(0, 255)) for i in xrange(n))
+    response.data = os.urandom(n)
     response.content_type = 'application/octet-stream'
     return response
 
@@ -481,7 +481,7 @@ def stream_random_bytes(n):
         chunks = []
 
         for i in xrange(n):
-            chunks.append(chr(random.randint(0, 255)))
+            chunks.append(os.urandom(1))
             if len(chunks) == chunk_size:
                 yield(bytes().join(chunks))
                 chunks = []
